Module allocator

Module allocator 

An allocator that enables tracking of allocations and deallocations for allocation groups (e.g. spans).

Structs

TrackingAllocator
An allocator that tracks allocations and deallocations.

Functions

flush_thread_statistics
Flush the statistics of the current thread so that it can be collected by the global tracker.