flush_thread_statistics

Function flush_thread_statistics 

pub fn flush_thread_statistics()
Flush the statistics of the current thread so that it can be collected by the global tracker.

This usually does not need to be called manually, it is done automatically when the thread exits or a span is exited or closed.