pub struct TrackingAllocator<A = System> { /* private fields */ }Expand description
An allocator that tracks allocations and deallocations.
The allocator works by tagging each allocation with a group ID in the first 8 bytes of the allocation.
Allocations are first tracked for each thread locally then periodically
reported to the global tracker via flush_thread_statistics.
The allocations and deallocations are only reported if a group ID is set, however the tagging is always done, so a tiny memory and bookkeeping overhead is incurred.
Implementations
Sourceimpl<A> TrackingAllocator<A>
impl<A> TrackingAllocator<A>