Module layer

Module layer 

A profiling layer that can be used with tracing-subscriber to track and report performance statistics.

Structs

ProfileLayer
A layer that tracks and reports profiling data.
ShutdownHandle
A handle that can be used to shutdown the profiling layer.