pub struct ShutdownHandle { /* private fields */ }Expand description
A handle that can be used to shutdown the profiling layer.
It will signal the reporter thread to shutdown and wait for it to finish. This is useful to ensure that all data is flushed before the process exits.
The shutdown procedure is also done when the ShutdownHandle is dropped.
Implementations