pub struct SpanWallTime {
pub elapsed_busy_nanos: u64,
pub elapsed_idle_nanos: u64,
}Expand description
Wall time statistics for a span.
Fields
elapsed_busy_nanos: u64The elapsed wall time in nanoseconds while the span was entered.
elapsed_idle_nanos: u64The elapsed wall time in nanoseconds while the span was idle.