An allocator that enables tracking of allocations and deallocations for allocation groups (e.g. spans).
Structs
- Tracking
Allocator - An allocator that tracks allocations and deallocations.
Functions
- flush_
thread_ statistics - Flush the statistics of the current thread so that it can be collected by the global tracker.