A profiling layer that can be used with tracing-subscriber to
track and report performance statistics.
Structs
- Profile
Layer - A layer that tracks and reports profiling data.
- Shutdown
Handle - A handle that can be used to shutdown the profiling layer.